==> haskell-authenticate-oauth-1.7-222-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-9jdk6AEbNllDkFIRS4Qj4D
key:                  authenticate-oauth-1.7-9jdk6AEbNllDkFIRS4Qj4D
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  a6eecd2ee3f5e2025130b7023a891eb1
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-9jdk6AEbNllDkFIRS4Qj4D
depends:
    RSA-2.4.1-GQZUTmX1Sb51tNVunHMtDt SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    base-4.16.4.0 base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    crypto-pubkey-types-0.4.3-3XvLXrfePwjIsbCkiJhvL8
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-GFtj4cUUjxDGnZKaI4AjE1
    http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4 time-1.11.1.1
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.7-232-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-1TWMzmgWhZ99FJ9ygZZtsL
key:                  authenticate-oauth-1.7-1TWMzmgWhZ99FJ9ygZZtsL
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  a669c26981a5982f7d5d2c615b6550fb
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-1TWMzmgWhZ99FJ9ygZZtsL
depends:
    RSA-2.4.1-BVV6eOSj6o4L91De7WHCzc SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    base-4.16.4.0 base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    crypto-pubkey-types-0.4.3-FODgSNFAve39E65iS9QFGb
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh time-1.11.1.1
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
